<?php
/**
  * Enviar correo de encuesta despues de un pedido
  * Version 1.0
  * Author Juan Castells
  * copyright 2013 www.juancastells.com
  *
  */

if (!defined('_PS_VERSION_'))
	exit;

class Encuesta extends Module
{
	private $_html = '';
	private $_postErrors = array();

	public function __construct()
	{
		$this->name = 'encuesta';
		$this->tab = 'administration';
		$this->version = '1.0';
		$this->author = 'Juan Castells';
		$this->need_instance = 1;

		parent::__construct();
		
		if ($this->id)
			$this->_refreshProperties();

		$this->displayName = $this->l('Encuesta de satisfaccion');
		$this->description = $this->l('Envia e-mail con enlace a encuesta de satisfaccion despues de un tiempo desde la entrega del pedido.');
		$this->confirmUninstall = $this->l('>Estas seguro que deseas desistalar este mdulo?');
	}

	public function install()
	{
		return parent::install() 
		&& 	Configuration::updateValue('ENCUESTA_ENLACE', "") 
		&&	Configuration::updateValue('ENCUESTA_DIAS', 15) 
		&& 	DB::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'orders` ADD (encuesta INT(11) NOT NULL DEFAULT 0)');
	}

	public function uninstall()
	{
		return Configuration::deleteByName('ENCUESTA_ENLACE') && Configuration::deleteByName('ENCUESTA_DIAS') &&
		DB::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'orders` DROP COLUMN `encuesta`') && parent::uninstall();
	}
	
	private function _refreshProperties()
	{
		$this->_enlace = Configuration::get('ENCUESTA_ENLACE');
		$this->_dias = (int)Configuration::get('ENCUESTA_DIAS');
	}


	public function getContent()
	{
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_postProcess();
		$this->_displayForm();
		return $this->_html;
	}

	private function _displayForm()
	{
		global $currentIndex;

		$tab = Tools::getValue('tab');
		$token = Tools::getValue('token');

		$this->_html .= '
		<form action="'.$currentIndex.'&token='.$token.'&configure=encuesta" method="post">
			<fieldset class="width3"><legend><img src="'.$this->_path.'logo.gif" />'.$this->l('Configuracion').'</legend>
				<label>'.$this->l('Url de la encuesta:').' </label>
				<div class="margin-form">
					<input type="text" name="ENCUESTA_ENLACE" value="'.(Tools::getValue('ENCUESTA_ENLACE') != null ? htmlentities(Tools::getValue('ENCUESTA_ENLACE')) : Configuration::get('ENCUESTA_ENLACE')).'"/>
					<p>'.$this->l('Enlace que aprecera en el correo. Ejemplo: http://www.encuestas.es/satisfacccion/miweb.html').'</p>
				</div>
				<label>'.$this->l('Dias para el envio de correo:').' </label>
				<div class="margin-form">
					<input type="text" name="ENCUESTA_DIAS" value="'.(Tools::getValue('ENCUESTA_DIAS') != null ? (int)(Tools::getValue('ENCUESTA_DIAS')) : Configuration::get('ENCUESTA_DIAS')).'" size="3" />
					<p>'.$this->l('Dias desde que el pedido pasa a entregado hasta que se envia el correo de satisfacion').'</p>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Guardar   ').'" name="submitConfEncuesta" class="button" />
				</div>
			</fieldset>
		<br />
			<fieldset style="margin-top:20px">

				<legend><img src="../img/admin/tab-tools.gif" />'.$this->l('Envio automatico de correos de encuesta').'</legend>

				<p>'.$this->l('Coloque esta URL en el crontab o llamela de forma manual todos los dias, tiene que haber introducido un numero de dias').'<br />

				<b>'.Tools::getShopDomain(true, true). __PS_BASE_URI__.'modules/encuesta/cron_encuesta.php?secure_key='.md5(_COOKIE_KEY_.Configuration::get('PS_SHOP_NAME')).'</b></p>

			</fieldset>
			
		</form>';
	}

	private function _postProcess()
	{
		if (Tools::isSubmit('submitConfEncuesta'))
		{
			if (!Configuration::updateValue('ENCUESTA_ENLACE', Tools::getValue('ENCUESTA_ENLACE')) || !Configuration::updateValue('ENCUESTA_DIAS', (int)Tools::getValue('ENCUESTA_DIAS')) )
				$this->_html .= '<div class="alert error">'.$this->l('Cannot update settings').'</div>';
			else
				$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.$this->l('Settings updated').'</div>';
		}
		
		$this->_refreshProperties();
	}
	
	public function diff_sinp($fecha1,$fecha2,$tiempo1,$tiempo2,$tipo){
	   //diferencia por horas:
	   $dif = date("H:i", strtotime("00:00") + strtotime($tiempo2) - strtotime($tiempo1));
	   if($dif == '00:00'){
		  $dif = null;
	   }
	   //diferencia por dias:
	   $difd = date_diff(date_create($fecha1),date_create($fecha2));
	   $difd = $difd->format('%a');
	   
	   if($tipo=="h"){
		return $dif;
	   }elseif($tipo=="d"){
		return $difd;
	   }else{
		return $difd.' '.$dif;
	   }
}	

}